The partial-SAVE model. This model is correct only under very strong
assumptions, the solution is used as the initial value in the orthoDr
optimization.
pSAVE(x, a, r, ndr = 2, nslices0 = 2)A list consisting of:
The basis of central subspace, ordered by eigenvalues
A matrix for features (continuous only).
A vector of observed dose levels (continuous only).
A vector of reward (outcome).
The dimension structure
Number of slides used for save
Feng, Z., Wen, X. M., Yu, Z., & Zhu, L. (2013). On partial sufficient dimension reduction with applications to partially linear multi-index models. Journal of the American Statistical Association, 108(501), 237-246. DOI: tools:::Rd_expr_doi("10.1080/01621459.2012.746065")